#
# Conditional build:
%bcond_without	doc	# PDF documentation

# TODO:
# - python3 (3.3+) package
# - use system fonts:
#   /usr/lib/python2.7/site-packages/reportlab/fonts/VeraBI.ttf
# - Check if docs/*.pdf is generated using _installed_ ReportLab
#   so build may fail if ReportLab is not installed on builder
# - Standard T1 font curves (source1) maybe should be packaged in other package?

%define		module	ReportLab
Summary:	Python library for generating PDFs and graphics
Summary(pl.UTF-8):	Moduły Pythona do generowania PDF-ów oraz grafik
Name:		python-%{module}
Version:	3.0
Release:	2
License:	BSD-like
Group:		Libraries/Python
#Source0Download: https://bitbucket.org/rptlab/reportlab/downloads
Source0:	https://bitbucket.org/rptlab/reportlab/get/ReportLab_3_0.tar.bz2
# Source0-md5:	2c902ed7f6bf029cd0946858f0b2c07e
Source1:	http://www.reportlab.com/ftp/fonts/pfbfer.zip
# Source1-md5:	35d20e26490cb2a8646fab6276ac6a4c
Patch0:		%{name}-setup.patch
URL:		http://www.reportlab.org/
BuildRequires:	freetype-devel >= 2
BuildRequires:	libart_lgpl-devel >= 2
%{?with_doc:BuildRequires:	python-PIL}
BuildRequires:	python-devel >= 1:2.7
BuildRequires:	rpm-pythonprov
BuildRequires:	rpmbuild(macros) >= 1.219
BuildRequires:	unzip
Requires:	python >= 1:2.7
Requires:	python-PIL
Obsoletes:	ReportLab
Obsoletes:	python-ReportLab-barcode
Obsoletes:	python-ReportLab-renderPM
Obsoletes:	python-ReportLab-rl_accel
BuildRoot:	%{tmpdir}/%{name}-%{version}-root-%(id -u -n)

%description
A library written in Python that lets you generate platform
independant PDFs and graphics.
- PDF generation: uses Python, a clean OO language, layered
  architecture
- Graphics: provides primitive shapes, reusable widgets, sample
  collections including business chart and diagrams
- PythonPoint: a utility for generating PDF slides from a simple XML
  format

%description -l pl.UTF-8
Biblioteka napisana w Pythonie pozwalająca na generowanie niezależnych
od platformy PDF-ów oraz grafik.
- Generowanie PDF: używa Pythona, przejrzystego języka obiektowego o
  warstwowej architekturze
- Grafika: podstawowe figury geometryczne, kontrolki, a także
  przykłady, w tym wykresy i diagramy
- PythonPoint: narzędzie do generowania slajdów w formacie PDF z
  prostego formatu XML

%package examples
Summary:	Examples for ReportLab
Summary(pl.UTF-8):	Przykłady do biblioteki ReportLab
Group:		Libraries/Python
Requires:	%{name} = %{version}-%{release}

%description examples
Examples for ReportLab.

%description examples -l pl.UTF-8
Przykłady do biblioteki ReportLab.

%prep
%setup -q -n rptlab-reportlab-6382a792db9e

%{__unzip} -qq -d src/reportlab/fonts %{SOURCE1}

%build
CC="%{__cc}" \
CFLAGS="%{rpmcflags}" \
%{__python} setup.py build
%if %{with doc}
cd docs
PYTHONPATH=$(pwd)/../src %{__python} genAll.py
cd ..
%endif

%install
rm -rf $RPM_BUILD_ROOT
%{__python} setup.py install \
	--root=$RPM_BUILD_ROOT \
	--optimize=2

install -d $RPM_BUILD_ROOT{%{_bindir},%{_examplesdir}/%{name}-%{version}}
install -p tools/pythonpoint/pythonpoint.py $RPM_BUILD_ROOT%{_bindir}

install -d $RPM_BUILD_ROOT%{py_sitescriptdir}/reportlab

cp -a demos $RPM_BUILD_ROOT%{_examplesdir}/%{name}-%{version}
cp -a tools/pythonpoint/demos $RPM_BUILD_ROOT%{_examplesdir}/%{name}-%{version}/pythonpoint-demos

%{__rm} -r $RPM_BUILD_ROOT%{py_sitedir}/reportlab/graphics/samples

%py_postclean

%clean
rm -rf $RPM_BUILD_ROOT

%files
%defattr(644,root,root,755)
%doc CHANGES.txt LICENSE.txt README.txt %{?with_doc:docs/reportlab-userguide.pdf}
%attr(755,root,root) %{_bindir}/pythonpoint.py
%dir %{py_sitescriptdir}/reportlab
%dir %{py_sitedir}/reportlab
%{py_sitedir}/reportlab-%{version}-py*.egg-info
%{py_sitedir}/reportlab/*.py[co]
%dir %{py_sitedir}/reportlab/fonts
%{py_sitedir}/reportlab/fonts/00readme.txt
# Dark Garden font (GPL v2+)
%{py_sitedir}/reportlab/fonts/DarkGardenMK.afm
%{py_sitedir}/reportlab/fonts/DarkGardenMK.pfb
%{py_sitedir}/reportlab/fonts/DarkGarden.sfd
%{py_sitedir}/reportlab/fonts/DarkGarden-*.txt
# Bitstream Vera font
%{py_sitedir}/reportlab/fonts/Vera*.ttf
%{py_sitedir}/reportlab/fonts/bitstream-vera-license.txt
# Adobe fonts
%{py_sitedir}/reportlab/fonts/_a*____.pfb
%{py_sitedir}/reportlab/fonts/_e*____.pfb
%{py_sitedir}/reportlab/fonts/co*____.pfb
%{py_sitedir}/reportlab/fonts/sy______.pfb
%{py_sitedir}/reportlab/fonts/z?______.pfb
%dir %{py_sitedir}/reportlab/graphics
%attr(755,root,root) %{py_sitedir}/reportlab/graphics/_renderPM.so
%{py_sitedir}/reportlab/graphics/*.py[co]
%dir %{py_sitedir}/reportlab/graphics/barcode
%{py_sitedir}/reportlab/graphics/barcode/*.py[co]
%dir %{py_sitedir}/reportlab/graphics/charts
%{py_sitedir}/reportlab/graphics/charts/*.py[co]
%dir %{py_sitedir}/reportlab/graphics/widgets
%{py_sitedir}/reportlab/graphics/widgets/*.py[co]
%dir %{py_sitedir}/reportlab/lib
%attr(755,root,root) %{py_sitedir}/reportlab/lib/_rl_accel.so
%attr(755,root,root) %{py_sitedir}/reportlab/lib/pyHnj.so
%{py_sitedir}/reportlab/lib/*.py[co]
%{py_sitedir}/reportlab/lib/hyphen.mashed
%dir %{py_sitedir}/reportlab/pdfbase
%{py_sitedir}/reportlab/pdfbase/*.py[co]
%dir %{py_sitedir}/reportlab/pdfgen
%{py_sitedir}/reportlab/pdfgen/*.py[co]
%dir %{py_sitedir}/reportlab/platypus
%{py_sitedir}/reportlab/platypus/*.py[co]

%files examples
%defattr(644,root,root,755)
%dir %{_examplesdir}/%{name}-%{version}
%{_examplesdir}/%{name}-%{version}/demos
%{_examplesdir}/%{name}-%{version}/pythonpoint-demos
%changelog
* Sun Mar 01 2015 PLD Linux Team <feedback@pld-linux.org>
- For complete changelog see: http://git.pld-linux.org/?p=packages/python-ReportLab.git;a=log;h=master

* Sun Mar 01 2015 Elan Ruusamäe <glen@delfi.ee> 0ed7b68
- x32 rebuild
- release 2 (by relup.sh)

* Sat Dec 27 2014 Jakub Bogusz <qboosh@pld-linux.org> 4eeb088
- typo, dropped redundant pyrequires_eq

* Sat Dec 27 2014 Jakub Bogusz <qboosh@pld-linux.org> 3000cab
- updated to 3.0 (supports python 2.7+/3.3+)

* Thu Sep 15 2011 Patryk Zawadzki <patrys@room-303.com> bd51404
- 2.5

* Tue Feb 08 2011 sparky <sparky@pld-linux.org> 0eb43df
- BR: unzip

* Tue Feb 08 2011 Elan Ruusamäe <glen@pld-linux.org> 4552da1
- pass CC to python build
- download .pfb fonts ourselves, instead letting setup.py doing it

* Sat Nov 13 2010 pawelz <pawelz@pld-linux.org> 6c665c7
- release 5

* Fri Nov 12 2010 Szymon Siwek <sls@pld-linux.org> c5ba6e3
- create missing sitescriptdir/reportlab dir

* Sun Sep 12 2010 Elan Ruusamäe <glen@pld-linux.org> c2fda9e
- package %{py_sitescriptdir}/reportlab; for python-ReportLab-barcode

* Thu Jul 08 2010 Arkadiusz Miśkiewicz <arekm@maven.pl> 2395c0c
- rel 3; doc build

* Thu Jul 08 2010 Arkadiusz Miśkiewicz <arekm@maven.pl> 89a10fd
- fix PYTHONPATH for docs generation

* Thu Jul 08 2010 Arkadiusz Miśkiewicz <arekm@maven.pl> 1a1c17b
- release 2

* Thu Jun 17 2010 Patryk Zawadzki <patrys@room-303.com> 54ccff6
- 2.4

* Wed Jul 08 2009 Mateusz Korniak <matkor@pld-linux.org> 52d263b
- Release 2. Lowered BR: python-devel >= 1:2.4.

* Wed Jul 08 2009 Patryk Zawadzki <patrys@room-303.com> aa5eb84
- 2.3
- comes with all bells and whistles
- no longer noarch
- TODO: rename to python-reportlab

* Fri Oct 03 2008 Arkadiusz Miśkiewicz <arekm@maven.pl> a615ca4
- release 2

* Mon Nov 19 2007 Patryk Zawadzki <patrys@room-303.com> 29650ea
- noarch

* Mon Nov 19 2007 Patryk Zawadzki <patrys@room-303.com> 74b8013
- proper patch (fixes a bug in setup.py)
- use setup.py properly instead of ripping parts of it

* Fri Nov 16 2007 Szymon Siwek <sls@pld-linux.org> 738cd61
- added setup.patch
- package to py_sitescriptdir again

* Fri Nov 16 2007 Szymon Siwek <sls@pld-linux.org> fbe0a87
- block search rl_accel files ("--rl_accel=No" doesn't work properly)

